@@ -1,5 +1,5 @@
 // GUI_About - About interface of MediaInfo
-// Copyright (C) 2002-2010 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2002-2011 MediaArea.net SARL, Info@MediaArea.net
 //
 // This program is free software: you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License as published by
@@ -38,9 +38,9 @@ TAboutF *AboutF;
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-const ZenLib::Char* MEDIAINFO_ABOUT=     _T("MediaInfo X.X.X.X\\r\\nCopyright (C) 2002-2009 Jerome Martinez");
+const ZenLib::Char* MEDIAINFO_ABOUT=     _T("MediaInfo X.X.X.X\\r\\nCopyright (C) 2002-2011 MediaArea.net SARL");
 const ZenLib::Char* MEDIAINFO_URL=       _T("http://mediainfo.sourceforge.net");
-const ZenLib::Char* MEDIAINFO_NEWVERSION=_T("http://sourceforge.net/project/showfiles.php?group_id=86862&package_id=90341");
+const ZenLib::Char* MEDIAINFO_NEWVERSION=_T("http://sourceforge.net/projects/mediainfo/files/");
 const ZenLib::Char* MEDIAINFO_DONATE=    _T("http://mediainfo.sourceforge.net/Donate");
 const ZenLib::Char* MEDIAINFO_MAILTO=    _T("mailto:zenitram@users.sourceforge.net");
 //---------------------------------------------------------------------------
@@ -130,3 +130,10 @@ void __fastcall TAboutF::WebSiteClick(TObject *Sender)
 #endif //MEDIAINFOGUI_ABOUT_NO
 
 
+
+void __fastcall TAboutF::ToolButton3Click(TObject *Sender)
+{
+    ShellExecute(NULL, NULL, _T("http://digi-metrics.com/"), NULL, NULL, SW_SHOWNORMAL);
+}
+//---------------------------------------------------------------------------
+
