@@ -38,7 +38,9 @@ Ztring Language_Others_Run ()
     ZtringListListF Dest;
     Dest.Load(L"../Source/Ressource/Language.csv");
 
+    Run_File(Dest, L"ar");
     Run_File(Dest, L"be");
+    Run_File(Dest, L"bg");
     Run_File(Dest, L"ca");
     Run_File(Dest, L"cs");
     Run_File(Dest, L"da");
@@ -49,8 +51,10 @@ Ztring Language_Others_Run ()
     Run_File(Dest, L"fr");
     Run_File(Dest, L"gl");
     Run_File(Dest, L"gr");
-    Run_File(Dest, L"hu");
     Run_File(Dest, L"hr");
+    Run_File(Dest, L"hu");
+    Run_File(Dest, L"hy");
+    Run_File(Dest, L"ka");
     Run_File(Dest, L"it");
     Run_File(Dest, L"ja");
     Run_File(Dest, L"ko");
